@@ -8,4 +8,4 @@ PICTURE_FORMATS = {
 TEMP_FOLDER = gettempdir()
 LOCAL_INTEGRATED_FOLDER = 'C:/Users/Public/Documents/Scala/LocalIntegratedContent'
 
-APIS = ['', 'BBC','NS','NU','TRAFFIC']
+APIS = ['', 'BBC','NS','NU','TRAFFIC','INSTAGRAM']
