@@ -45,6 +45,11 @@ def download_media(media_link, subdirectory, temp_folder):
     return media_path
 
 
+def install_media(media_link, subdirectory):
+    install_content(media_link, subdirectory)
+    return os.path.join('Content:\\', subdirectory, media_link.split('\\').pop())
+
+
 def purge_directories(directories, max_days):
     # Remove all files from directory that are older than max_days
     for directory in directories:
