@@ -74,24 +74,36 @@ def parse_string_time_to_minutes(element):
     return minutes
 
 
-def get_month_text(month_number, month_index):
+def get_month_text(month_number, month_index, language_index=1):
     return{
-        1: ['jan', 'januari'],
-        2: ['feb', 'februari'],
-        3: ['maa', 'maart'],
-        4: ['apr', 'april'],
-        5: ['mei', 'mei'],
-        6: ['jun', 'juni'],
-        7: ['jul', 'juli'],
-        8: ['aug', 'augustus'],
-        9: ['sep', 'september'],
-        10: ['okt', 'oktober'],
-        11: ['nov', 'november'],
-        12: ['dec', 'december']
-    }[month_number][month_index]
+        1: [['Jan', 'January'], ['jan', 'januari']],
+        2: [['Feb', 'February'], ['feb', 'februari']],
+        3: [['Mar', 'March'], ['maart', 'maart']],
+        4: [['Apr', 'April'], ['apr', 'april']],
+        5: [['May', 'May'], ['mei', 'mei']],
+        6: [['June', 'June'], ['juni', 'juni']],
+        7: [['July', 'July'], ['juli', 'juli']],
+        8: [['Aug', 'August'], ['aug', 'augustus']],
+        9: [['Sept', 'September'], ['sept', 'september']],
+        10: [['Oct', 'October'], ['okt', 'oktober']],
+        11: [['Nov', 'November'], ['nov', 'november']],
+        12: [['Dec', 'December'], ['dec', 'december']]
+    }[month_number][language_index][month_index]
 
 
 def parse_date_to_string_full_day_month(date_object, month_type):
     day = str(date_object.day)
-    month = get_month_text(date_object.month, month_type)
+    month = get_month_text(date_object.month, month_type, 1)
     return ' '.join([day, month, parse_date_to_string(date_object, '%Y %H:%M')])
+
+
+def parse_date_to_string_full_month_day(date_object, month_type):
+    day = str(date_object.day)
+    month = get_month_text(date_object.month, month_type, 0)
+    return ' '.join([month, day, parse_date_to_string(date_object, '%Y %H:%M')])
+
+def parse_date_to_string_full(date_object, month_type, language_index):
+    if language_index == 1:
+        return parse_date_to_string_full_day_month(date_object, month_type)
+    else:
+        return parse_date_to_string_full_month_day(date_object, month_type)
